/* 
   astwar - AstWar is a terminal based 2D space shooter.

   Copyright (C) 2002 Frederico S. Munoz

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  

#include <termios.h>
#include <grp.h>
#include <pwd.h>
*/

#include <stdio.h>
#include <sys/types.h>
#include <getopt.h>
#include "system.h"
#include <curses.h>
#include "general.h"
#include "shoot.h"
#include "movement.h"


#define EXIT_FAILURE 1

char *xmalloc ();
char *xrealloc ();
char *xstrdup ();

int mcol = 2;
int mrow = 1;

const int fake_row = 0;
const int fake_col = 0;

static struct ship ship1;
static struct ship ship2;
static char last_command1;
static char last_command2;

int last_shot1 = 0;		/* This is to store the number of
 				   active shots */
int last_shot2 = 0;
	
struct shot mshots1[20];	/* Struct that holds the shots */
struct shot mshots2[20];	/* Struct that holds the shots */




static void usage (int status);
static void move_ship (struct ship *mship, int command);

/* The name the program was run with, stripped of any leading path. */
static char *program_name;

/* getopt_long return codes */
enum {DUMMY_CODE=129
};

/* Option flags and variables */


static struct option const long_options[] =
{
  {"help", no_argument, 0, 'h'},
  {"version", no_argument, 0, 'V'},
  {NULL, 0, NULL, 0}
};

static int decode_switches (int argc, char **argv);

int
main (int argc, char **argv)
{
  int i;

  program_name = argv[0];

  i = decode_switches (argc, argv);
  init_curses();
  
  ship1.col = 1;
  ship1.row = LINES / 2;
  ship1.id = 1;

  ship2.col = COLS - 2;
  ship2.id = 2;
  ship2.row=LINES /2;
  
  mvaddstr (ship1.row, ship1.col, "*"); 
  mvaddstr (ship2.row, ship2.col, "*"); 


  draw_arena();
  for(;;)
    {
      int  command = getch();
      move_ship(&ship1, command);
      move_ship(&ship2, command);  
    
      draw_shots(&ship1); 
      draw_shots(&ship2);   
      shoot_torpedo(&ship1);
      check_hit (&ship1, &ship2);
      /*exit(0);*/
      
      (void) doupdate();
      /* refresh(); */
    }
  
  finish(0);               /* we're done */
  exit (0);
}

/* Set all the option flags according to the switches specified.
   Return the index of the first non-option argument.  */

static int
decode_switches (int argc, char **argv)
{
  int c;

  ship1.nshots = 0;

  while ((c = getopt_long (argc, argv, 
			   "h"	/* help */
			   "V",	/* version */
			   long_options, (int *) 0)) != EOF)
    {
      switch (c)
	{
	case 'V':
	  printf ("astwar %s\n", VERSION);
	  exit (0);

	case 'h':
	  usage (0);

	default:
	  usage (EXIT_FAILURE);
	
	}
    }

  return optind;
}


static void
usage (int status)
{
  printf (_("%s - \
AstWar is a terminal based 2D space shooter.\n"), program_name);
  printf (_("Usage: %s [OPTION]... [FILE]...\n"), program_name);
  printf (_("\
Options:\n\
  -h, --help                 display this help and exit\n\
  -V, --version              output version information and exit\n\
"));
  exit (status);
}

static void
move_ship (struct ship *mship, int command)
{
  


 if (mship->id == 1)
   { 
     if (command == 'q' || command == KEY_UP)
       {
	 move_up(mship);
	 last_command1 = 'q';
       }
     else if (command == 'a' || command == KEY_DOWN) 
       {
	 move_down(mship);
	 last_command1 = 'a';
       }
     else if (command == 'e')
       {
	 shoot(mship);
       }
     else if (command == 'h')
       {
	 storp(mship);
       }
     else if (last_command1 == 'q')
       {
      move_up(mship);
       }
     else if (last_command1 == 'a')
       {
	 move_down(mship);
       }
   }
 
 
 if (mship->id == 2)
   { 
     if (command == 'i' || command == KEY_UP)
       {
	 move_up(mship);
	 last_command2 = 'i';
       }
     else if (command == 'k' || command == KEY_DOWN) 
       {
	 move_down(mship);
	 last_command2 = 'k';
       }
     else if (command == 'y')
       {
	 shoot(mship);
       }
     else if (last_command2 == 'i')
       {
	 move_up(mship);
       }
     else if (last_command2 == 'k')
       {
	 move_down(mship);
       }
   }
  
}

