/* 
   astwar - terminal based 2D space shooter.

   Copyright (C) 2002 Frederico S. Munoz, Jorge Monteiro

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  
*/

#include <curses.h>
#include <signal.h>
#include <pthread.h>
#include <unistd.h>
#include "general.h"
#include "shoot.h"

extern int last_shot1;		/* This is to store the number of
 				   active shots */
extern int last_shot2;
	
extern struct shot mshots1[20];	/* Struct that holds the shots */
extern struct shot mshots2[20];	/* Struct that holds the shots */

extern int score1;
extern int score2;

extern pthread_t ps1;
extern pthread_t ps2;
pthread_t mt;

/* Catch the SIGKILL and exit gracefully */
void finish(int sig)
{
  pthread_join(ps1, NULL);
  pthread_join(ps2, NULL);
  pthread_join(mt, NULL);
  endwin();
  
  /* do your non-curses wrapup here */
  
  exit(0);
}

void 
handle_winch (int sig)
{
  endwin();
  init_curses();
  clear();
  refresh();
  draw_arena();
 
}

void
init_curses (void)
{
  
  
  (void) signal(SIGINT, finish);      /* arrange interrupts to terminate */
  (void) signal(SIGWINCH, handle_winch);
  (void) initscr();      /* initialize the curses library */
  (void) keypad(stdscr, TRUE);  /* enable keyboard mapping */
  (void) nonl();         /* tell curses not to do NL->CR/NL on output */
  (void) nocbreak();       /* take input chars one at a time, no wait for \n */
  (void) noecho();         /* echo input - in color */
  (void) nodelay(stdscr, TRUE);
  (void) typeahead (TRUE);
  (void) leaveok(stdscr, TRUE);
  (void) curs_set (0);
  if (has_colors())
    {
      start_color();
      
      /*
       * Simple color assignment, often all we need.  Color pair 0 cannot
       * be redefined.  This example uses the same value for the color
       * pair as for the foreground color, though of course that is not
       * necessary:
       */
      init_pair(1, COLOR_RED,     COLOR_BLACK);
      init_pair(2, COLOR_GREEN,   COLOR_BLACK);
      init_pair(3, COLOR_YELLOW,  COLOR_BLACK);
      init_pair(4, COLOR_BLUE,    COLOR_BLACK);
      init_pair(5, COLOR_CYAN,    COLOR_BLACK);
      init_pair(6, COLOR_MAGENTA, COLOR_BLACK);
      init_pair(7, COLOR_WHITE,   COLOR_BLACK);
    }
 }


void
my_refresh (void)
{
  wnoutrefresh(stdscr);
 
}

void
wmenu (char *message)
{
  mvaddstr (0, 0, message);
}

void
wdmenu (char *message)
{
  mvaddstr (LINES, 56, message);
}
void
wmenu2 (char *message)
{
  mvaddstr (0, 0, message);
}

void
wdmenu2 (char *message)
{
  mvaddstr (0, LINES, message);
}

void
draw_arena (void)
{
  box (stdscr, 0, 0);
  mvvline (1, (COLS / 2), '.', (LINES - 2));
}

void*
blop (void* arg)
{
  register int count = 1;
  char *message = "You have hit the other ship!";
  while (*message)
    {
      usleep(1);
      mvaddch(0,90 + count,*message);
      (void) *message++;
      count++;
    }
  mvaddstr (0,90, "                              ");
  return NULL;
}

void
check_hit (struct ship *mship1, struct ship *mship2)
{
  register int t;

  for (t=0; t < 20; t++)
    {
      if (mshots1[t].col == (mship2->col - 1) && mshots1[t].row == mship2->row  && mshots1[t].active == 1)
	{

	  pthread_create (&mt, NULL, blop, NULL);
	  pthread_detach(mt);
	  mshots1[t].active = 0;
	  mvaddstr(mshots1[t].row, (mshots1[t].col - 1), " ");
	  score1 += 1;
	  wdmenu2 ("Score: ");
	  printw("Ship1: %d\t Ship2: %d", score1, score2);

	}
          } 
  
  for (t=0; t < 20; t++)
    {
      if (mshots2[t].col == (mship1->col + 1) && mshots2[t].row == mship1->row && mshots2[t].active == 1)
	{
	  pthread_create (&mt, NULL, blop, NULL);
	  pthread_detach(mt);
	  score2 += 1;
	  mshots2[t].active = 0;
	  mvaddstr(mshots2[t].row, (mshots2[t].col + 1), " ");
	  wdmenu2 ("Score: ");
	  printw("Ship1: %d\t Ship2: %d", score1, score2);

	} 
    }
  
}
